# allianceauth-app-utils

![release](https://img.shields.io/pypi/v/allianceauth-app-utils?label=release) ![python](https://img.shields.io/pypi/pyversions/allianceauth-app-utils) ![django](https://img.shields.io/pypi/djversions/allianceauth-app-utils?label=django) ![pipeline](https://gitlab.com/ErikKalkoken/allianceauth-app-utils/badges/master/pipeline.svg) ![coverage](https://gitlab.com/ErikKalkoken/allianceauth-app-utils/badges/master/coverage.svg) ![license](https://img.shields.io/badge/license-MIT-green) ![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)

Commonly used utility functions and classes for rapid development of Alliance Auth apps.

## Description

This package contains a variety of commonly used utility functions and classes that help speed up development of Alliance Auth apps and reduce code duplication across apps.
